<template>
  <div class="system-gas-container">
    <el-card shadow="hover">
      <div class="system-menu-search mb15">
        <el-form :inline="true" style="display: flex;align-items: flex-start;flex-wrap: wrap" >
          <el-form-item label="日期：" >
            <el-date-picker
                v-model="state.tableData.listQuery.searchParams.time"
                type="datetimerange"
                format="YYYY-MM-DD HH:mm:ss"
                value-format="YYYY-MM-DD HH:mm:ss"
                range-separator="~"
                start-placeholder="开始时间"
                end-placeholder="结束时间"
            />
          </el-form-item>
          <el-button size="default" type="primary" class="ml10" @click="search()">
            <el-icon>
              <ele-Search />
            </el-icon>
            查询
          </el-button>
          <el-button size="default" class="ml10" @click="reset()">
            <el-icon>
              <RefreshLeft />
            </el-icon>
            重置
          </el-button>
        </el-form>
      </div>
      <el-table :data="state.tableData.data" style="width: 100%">
        <el-table-column align="center" prop="content"  label="预警内容"/>
        <el-table-column align="center" prop="time"  label="预警时间"/>
        <el-table-column label="操作" show-overflow-tooltip width="140">
          <template #default="scope">
            <el-button size="small" text type="primary" @click="openDialog('查看', scope.row)">查看</el-button>
          </template>
        </el-table-column>
      </el-table>
      <br />
      <el-pagination
          @size-change="onHandleSizeChange"
          @current-change="onHandleCurrentChange"
          class="page-position"
          :pager-count="5"
          :page-sizes="[10, 20, 30]"
          v-model:current-page="state.tableData.listQuery.pageIndex"
          background
          v-model:page-size="state.tableData.listQuery.pageSize"
          layout="total, sizes, prev, pager, next, jumper"
          :total="state.tableData.total">
      </el-pagination>
      <br />
      <br />
    </el-card>
    <info-dialog ref="infoRef" @getInfoData="initInfoData"></info-dialog>
  </div>
</template>

<script setup lang="ts">
import {reactive, ref, onMounted} from "vue";
import { ElMessage, ElMessageBox } from 'element-plus';
import infoDialog from "./component/index.vue";
import {warningInfoApi} from "/@/api/warningManage/warningInfo";

const infoRef = ref();
const state = reactive({
  tableData: {
    data: [] as any,
    total: 0,
    loading: false,
    listQuery: {
      pageIndex: 1,
      pageSize: 10,
      searchParams: {
        time: []
      }
    },
  }
});

//页面加载
onMounted(() => {
  initInfoData();
});


//预警信息列表
const initInfoData = async () => {
  const param = {
    pageIndex: state.tableData.listQuery.pageIndex,
    pageSize: state.tableData.listQuery.pageSize,
    searchParams: {
      startTime: state.tableData.listQuery.searchParams.time ? state.tableData.listQuery.searchParams.time[0] : '',
      endTime: state.tableData.listQuery.searchParams.time ? state.tableData.listQuery.searchParams.time[1]: ''
    }
  };
  let res = await warningInfoApi().getWarnDeviceLogPage(param);
  if(res.data.code == 100) {
    state.tableData.data = res.data.data;
    state.tableData.total = res.data.total;
    state.tableData.listQuery.pageIndex = res.data.pageIndex;
    state.tableData.listQuery.pageSize = res.data.pageSize;
  }else {
    ElMessage({
      type: 'warning',
      message: res.data.msg
    });
  }
};
const onHandleSizeChange = (val: number) => {
  state.tableData.listQuery.pageSize = val;
  initInfoData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
  state.tableData.listQuery.pageIndex = val;
  initInfoData();
};
const openDialog = (type: string, value: any) => {
  infoRef.value.openDialog(type, value);
};

const search = () => {
  state.tableData.listQuery.pageIndex = 1;
  initInfoData();
}
const reset = () => {
  state.tableData.listQuery.pageIndex = 1;
  state.tableData.listQuery.searchParams.time = [];
  initInfoData();
}
</script>
<style scoped lang="scss">
.yellow{
  width: 80px;
  height: 30px;
  background-color: rgb(255,223,37);
  line-height: 30px;
  color: white;
  box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
  padding: 3px
}
.red{
  width: 80px;
  height: 30px;
  background-color: rgb(239,90,161);
  line-height: 30px;
  color: white;
  box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
  padding: 3px
}
</style>
